@@ -36,7 +36,7 @@ def open_observed_and_models(obs,modelo,proy,var,f_clim,f_pro,anual=False):
         model=model[var].sel(time=slice(f_clim[0],f_clim[1]))
         #PARA ANUAL O MENSUAL
         if anual==True:
-            tiempos=pd.date_range(start=f_clim[0],freq='YS',periods=len(obs.time))
+            tiempos=pd.date_range(start=f_clim[0],freq='YS',periods=len(model.time))
         else:
             tiempos=pd.date_range(start=f_clim[0],freq='MS',periods=len(model.time))
         ################################################################
@@ -45,7 +45,7 @@ def open_observed_and_models(obs,modelo,proy,var,f_clim,f_pro,anual=False):
         proyec=proyec[var].sel(time=slice(f_pro[0],f_pro[1]))
         #PARA ANUAL O MENSUAL
         if anual==True:
-            tiempos=pd.date_range(start=f_clim[0],freq='YS',periods=len(obs.time))
+            tiempos=pd.date_range(start=f_pro[0],freq='YS',periods=len(proyec.time))
         else:
             tiempos=pd.date_range(start=f_pro[0],freq='MS',periods=len(proyec.time))
         ################################################################
